@@ -1,7 +1,7 @@
 /**********
 This library is free software; you can redistribute it and/or modify it under
 the terms of the GNU Lesser General Public License as published by the
-Free Software Foundation; either version 2.1 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)
 
 This library is distributed in the hope that it will be useful, but WITHOUT
@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2016 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2019 Live Networks, Inc.  All rights reserved.
 // A class that encapsulates a Matroska file.
 // Implementation
 
@@ -33,6 +33,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include <VP8VideoRTPSink.hh>
 #include <VP9VideoRTPSink.hh>
 #include <TheoraVideoRTPSink.hh>
+#include <RawVideoRTPSink.hh>
 #include <T140TextRTPSink.hh>
 
 ////////// CuePoint definition //////////
@@ -437,6 +438,9 @@ RTPSink* MatroskaFile
       } while (0);
 
       delete[] identificationHeader; delete[] commentHeader; delete[] setupHeader;
+    } else if (strcmp(track->mimeType, "video/RAW") == 0) {
+      result = RawVideoRTPSink::createNew(envir(), rtpGroupsock, rtpPayloadTypeIfDynamic, 
+                                          track->pixelHeight, track->pixelWidth, track->bitDepth, track->colorSampling, track->colorimetry);
     } else if (strcmp(track->mimeType, "video/H264") == 0) {
       // Use our track's 'Codec Private' data: Bytes 5 and beyond contain SPS and PPSs:
       u_int8_t* SPS = NULL; unsigned SPSSize = 0;
@@ -668,7 +672,8 @@ MatroskaTrack::MatroskaTrack()
     codecPrivateSize(0), codecPrivate(NULL),
     codecPrivateUsesH264FormatForH265(False), codecIsOpus(False),
     headerStrippedBytesSize(0), headerStrippedBytes(NULL),
-    subframeSizeSize(0) {
+    colorSampling(""), colorimetry("BT709-2") /*Matroska default value for Primaries */,
+    pixelWidth(0), pixelHeight(0), bitDepth(8), subframeSizeSize(0) {
 }
 
 MatroskaTrack::~MatroskaTrack() {
